@@ -6,10 +6,11 @@ Type annotations for datasync service client.
 Usage::
 
     ```python
-    import boto3
-    from mypy_boto3_datasync import DataSyncClient
+    from boto3.session import Session
+    from mypy_boto3_datasync.client import DataSyncClient
 
-    client: DataSyncClient = boto3.client("datasync")
+    session = Session()
+    client: DataSyncClient = session.client("datasync")
     ```
 """
 import sys
@@ -33,6 +34,7 @@ from .paginator import (
 from .type_defs import (
     CreateAgentResponseTypeDef,
     CreateLocationEfsResponseTypeDef,
+    CreateLocationFsxLustreResponseTypeDef,
     CreateLocationFsxWindowsResponseTypeDef,
     CreateLocationHdfsResponseTypeDef,
     CreateLocationNfsResponseTypeDef,
@@ -42,6 +44,7 @@ from .type_defs import (
     CreateTaskResponseTypeDef,
     DescribeAgentResponseTypeDef,
     DescribeLocationEfsResponseTypeDef,
+    DescribeLocationFsxLustreResponseTypeDef,
     DescribeLocationFsxWindowsResponseTypeDef,
     DescribeLocationHdfsResponseTypeDef,
     DescribeLocationNfsResponseTypeDef,
@@ -96,7 +99,7 @@ class Exceptions:
 
 class DataSyncClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html)
     """
 
@@ -106,13 +109,16 @@ class DataSyncClient(BaseClient):
     def exceptions(self) -> Exceptions:
         """
         DataSyncClient exceptions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.exceptions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#exceptions)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#can_paginate)
         """
 
@@ -120,7 +126,7 @@ class DataSyncClient(BaseClient):
         """
         Cancels execution of a task.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.cancel_task_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.cancel_task_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#cancel_task_execution)
         """
 
@@ -137,7 +143,7 @@ class DataSyncClient(BaseClient):
         """
         Activates an DataSync agent that you have deployed on your host.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.create_agent)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_agent)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_agent)
         """
 
@@ -152,10 +158,25 @@ class DataSyncClient(BaseClient):
         """
         Creates an endpoint for an Amazon EFS file system.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.create_location_efs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_location_efs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_efs)
         """
 
+    def create_location_fsx_lustre(
+        self,
+        *,
+        FsxFilesystemArn: str,
+        SecurityGroupArns: Sequence[str],
+        Subdirectory: str = ...,
+        Tags: Sequence["TagListEntryTypeDef"] = ...
+    ) -> CreateLocationFsxLustreResponseTypeDef:
+        """
+        Creates an endpoint for an Amazon FSx for Lustre file system.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_location_fsx_lustre)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_fsx_lustre)
+        """
+
     def create_location_fsx_windows(
         self,
         *,
@@ -170,7 +191,7 @@ class DataSyncClient(BaseClient):
         """
         Creates an endpoint for an Amazon FSx for Windows File Server file system.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.create_location_fsx_windows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_location_fsx_windows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_fsx_windows)
         """
 
@@ -194,7 +215,7 @@ class DataSyncClient(BaseClient):
         """
         Creates an endpoint for a Hadoop Distributed File System (HDFS).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.create_location_hdfs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_location_hdfs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_hdfs)
         """
 
@@ -211,7 +232,7 @@ class DataSyncClient(BaseClient):
         Defines a file system on a Network File System (NFS) server that can be read
         from or written to.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.create_location_nfs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_location_nfs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_nfs)
         """
 
@@ -231,7 +252,7 @@ class DataSyncClient(BaseClient):
         """
         Creates an endpoint for a self-managed object storage bucket.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.create_location_object_storage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_location_object_storage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_object_storage)
         """
 
@@ -248,7 +269,7 @@ class DataSyncClient(BaseClient):
         """
         Creates an endpoint for an Amazon S3 bucket.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.create_location_s3)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_location_s3)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_s3)
         """
 
@@ -268,7 +289,7 @@ class DataSyncClient(BaseClient):
         Defines a file system on a Server Message Block (SMB) server that can be read
         from or written to.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.create_location_smb)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_location_smb)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_smb)
         """
 
@@ -288,7 +309,7 @@ class DataSyncClient(BaseClient):
         """
         Creates a task.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.create_task)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_task)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_task)
         """
 
@@ -296,7 +317,7 @@ class DataSyncClient(BaseClient):
         """
         Deletes an agent.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.delete_agent)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.delete_agent)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#delete_agent)
         """
 
@@ -304,7 +325,7 @@ class DataSyncClient(BaseClient):
         """
         Deletes the configuration of a location used by DataSync.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.delete_location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.delete_location)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#delete_location)
         """
 
@@ -312,7 +333,7 @@ class DataSyncClient(BaseClient):
         """
         Deletes a task.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.delete_task)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.delete_task)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#delete_task)
         """
 
@@ -321,7 +342,7 @@ class DataSyncClient(BaseClient):
         Returns metadata such as the name, the network interfaces, and the status (that
         is, whether the agent is running or not) for an agent.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.describe_agent)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_agent)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_agent)
         """
 
@@ -329,10 +350,21 @@ class DataSyncClient(BaseClient):
         """
         Returns metadata, such as the path information about an Amazon EFS location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.describe_location_efs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_location_efs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_efs)
         """
 
+    def describe_location_fsx_lustre(
+        self, *, LocationArn: str
+    ) -> DescribeLocationFsxLustreResponseTypeDef:
+        """
+        Returns metadata, such as the path information about an Amazon FSx for Lustre
+        location.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_location_fsx_lustre)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_fsx_lustre)
+        """
+
     def describe_location_fsx_windows(
         self, *, LocationArn: str
     ) -> DescribeLocationFsxWindowsResponseTypeDef:
@@ -340,7 +372,7 @@ class DataSyncClient(BaseClient):
         Returns metadata, such as the path information about an Amazon FSx for Windows
         File Server location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.describe_location_fsx_windows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_location_fsx_windows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_fsx_windows)
         """
 
@@ -349,7 +381,7 @@ class DataSyncClient(BaseClient):
         Returns metadata, such as the authentication information about the Hadoop
         Distributed File System (HDFS) location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.describe_location_hdfs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_location_hdfs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_hdfs)
         """
 
@@ -357,7 +389,7 @@ class DataSyncClient(BaseClient):
         """
         Returns metadata, such as the path information, about an NFS location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.describe_location_nfs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_location_nfs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_nfs)
         """
 
@@ -367,7 +399,7 @@ class DataSyncClient(BaseClient):
         """
         Returns metadata about a self-managed object storage server location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.describe_location_object_storage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_location_object_storage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_object_storage)
         """
 
@@ -375,7 +407,7 @@ class DataSyncClient(BaseClient):
         """
         Returns metadata, such as bucket name, about an Amazon S3 bucket location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.describe_location_s3)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_location_s3)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_s3)
         """
 
@@ -383,7 +415,7 @@ class DataSyncClient(BaseClient):
         """
         Returns metadata, such as the path and user information about an SMB location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.describe_location_smb)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_location_smb)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_smb)
         """
 
@@ -391,7 +423,7 @@ class DataSyncClient(BaseClient):
         """
         Returns metadata about a task.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.describe_task)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_task)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_task)
         """
 
@@ -401,7 +433,7 @@ class DataSyncClient(BaseClient):
         """
         Returns detailed metadata about a task that is being executed.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.describe_task_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_task_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_task_execution)
         """
 
@@ -415,7 +447,7 @@ class DataSyncClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#generate_presigned_url)
         """
 
@@ -426,7 +458,7 @@ class DataSyncClient(BaseClient):
         Returns a list of agents owned by an Amazon Web Services account in the Amazon
         Web Services Region specified in the request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.list_agents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.list_agents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#list_agents)
         """
 
@@ -440,7 +472,7 @@ class DataSyncClient(BaseClient):
         """
         Returns a list of source and destination locations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.list_locations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.list_locations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#list_locations)
         """
 
@@ -450,7 +482,7 @@ class DataSyncClient(BaseClient):
         """
         Returns all the tags associated with a specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#list_tags_for_resource)
         """
 
@@ -460,7 +492,7 @@ class DataSyncClient(BaseClient):
         """
         Returns a list of executed tasks.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.list_task_executions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.list_task_executions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#list_task_executions)
         """
 
@@ -474,7 +506,7 @@ class DataSyncClient(BaseClient):
         """
         Returns a list of all the tasks.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.list_tasks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.list_tasks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#list_tasks)
         """
 
@@ -489,7 +521,7 @@ class DataSyncClient(BaseClient):
         """
         Starts a specific invocation of a task.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.start_task_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.start_task_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#start_task_execution)
         """
 
@@ -499,7 +531,7 @@ class DataSyncClient(BaseClient):
         """
         Applies a key-value pair to an Amazon Web Services resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#tag_resource)
         """
 
@@ -507,7 +539,7 @@ class DataSyncClient(BaseClient):
         """
         Removes a tag from an Amazon Web Services resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#untag_resource)
         """
 
@@ -515,7 +547,7 @@ class DataSyncClient(BaseClient):
         """
         Updates the name of an agent.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.update_agent)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.update_agent)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#update_agent)
         """
 
@@ -540,7 +572,7 @@ class DataSyncClient(BaseClient):
         Updates some parameters of a previously created location for a Hadoop
         Distributed File System cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.update_location_hdfs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.update_location_hdfs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#update_location_hdfs)
         """
 
@@ -556,7 +588,7 @@ class DataSyncClient(BaseClient):
         Updates some of the parameters of a previously created location for Network File
         System (NFS) access.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.update_location_nfs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.update_location_nfs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#update_location_nfs)
         """
 
@@ -575,7 +607,7 @@ class DataSyncClient(BaseClient):
         Updates some of the parameters of a previously created location for self-managed
         object storage server access.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.update_location_object_storage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.update_location_object_storage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#update_location_object_storage)
         """
 
@@ -594,7 +626,7 @@ class DataSyncClient(BaseClient):
         Updates some of the parameters of a previously created location for Server
         Message Block (SMB) file system access.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.update_location_smb)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.update_location_smb)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#update_location_smb)
         """
 
@@ -612,7 +644,7 @@ class DataSyncClient(BaseClient):
         """
         Updates the metadata associated with a task.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.update_task)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.update_task)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#update_task)
         """
 
@@ -622,22 +654,22 @@ class DataSyncClient(BaseClient):
         """
         Updates execution of a task.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Client.update_task_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.update_task_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#update_task_execution)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_agents"]) -> ListAgentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Paginator.ListAgents)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listagentspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#get_paginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_locations"]) -> ListLocationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Paginator.ListLocations)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listlocationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#get_paginator)
         """
 
     @overload
@@ -645,8 +677,8 @@ class DataSyncClient(BaseClient):
         self, operation_name: Literal["list_tags_for_resource"]
     ) -> ListTagsForResourcePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listtagsforresourcepaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#get_paginator)
         """
 
     @overload
@@ -654,13 +686,13 @@ class DataSyncClient(BaseClient):
         self, operation_name: Literal["list_task_executions"]
     ) -> ListTaskExecutionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listtaskexecutionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#get_paginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_tasks"]) -> ListTasksPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/datasync.html#DataSync.Paginator.ListTasks)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listtaskspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#get_paginator)
         """
