@@ -16,6 +16,7 @@ from datetime import datetime
 from typing import IO, Dict, List, Sequence, Union
 
 from botocore.response import StreamingBody
+from typing_extensions import NotRequired
 
 from .literals import (
     AgentStatusType,
@@ -65,6 +66,8 @@ __all__ = (
     "CreateAgentResponseTypeDef",
     "CreateLocationEfsRequestRequestTypeDef",
     "CreateLocationEfsResponseTypeDef",
+    "CreateLocationFsxLustreRequestRequestTypeDef",
+    "CreateLocationFsxLustreResponseTypeDef",
     "CreateLocationFsxWindowsRequestRequestTypeDef",
     "CreateLocationFsxWindowsResponseTypeDef",
     "CreateLocationHdfsRequestRequestTypeDef",
@@ -86,6 +89,8 @@ __all__ = (
     "DescribeAgentResponseTypeDef",
     "DescribeLocationEfsRequestRequestTypeDef",
     "DescribeLocationEfsResponseTypeDef",
+    "DescribeLocationFsxLustreRequestRequestTypeDef",
+    "DescribeLocationFsxLustreResponseTypeDef",
     "DescribeLocationFsxWindowsRequestRequestTypeDef",
     "DescribeLocationFsxWindowsResponseTypeDef",
     "DescribeLocationHdfsRequestRequestTypeDef",
@@ -148,11 +153,10 @@ __all__ = (
 AgentListEntryTypeDef = TypedDict(
     "AgentListEntryTypeDef",
     {
-        "AgentArn": str,
-        "Name": str,
-        "Status": AgentStatusType,
+        "AgentArn": NotRequired[str],
+        "Name": NotRequired[str],
+        "Status": NotRequired[AgentStatusType],
     },
-    total=False,
 )
 
 CancelTaskExecutionRequestRequestTypeDef = TypedDict(
@@ -162,30 +166,17 @@ CancelTaskExecutionRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateAgentRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateAgentRequestRequestTypeDef",
+CreateAgentRequestRequestTypeDef = TypedDict(
+    "CreateAgentRequestRequestTypeDef",
     {
         "ActivationKey": str,
+        "AgentName": NotRequired[str],
+        "Tags": NotRequired[Sequence["TagListEntryTypeDef"]],
+        "VpcEndpointId": NotRequired[str],
+        "SubnetArns": NotRequired[Sequence[str]],
+        "SecurityGroupArns": NotRequired[Sequence[str]],
     },
 )
-_OptionalCreateAgentRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateAgentRequestRequestTypeDef",
-    {
-        "AgentName": str,
-        "Tags": Sequence["TagListEntryTypeDef"],
-        "VpcEndpointId": str,
-        "SubnetArns": Sequence[str],
-        "SecurityGroupArns": Sequence[str],
-    },
-    total=False,
-)
-
-
-class CreateAgentRequestRequestTypeDef(
-    _RequiredCreateAgentRequestRequestTypeDef, _OptionalCreateAgentRequestRequestTypeDef
-):
-    pass
-
 
 CreateAgentResponseTypeDef = TypedDict(
     "CreateAgentResponseTypeDef",
@@ -195,28 +186,15 @@ CreateAgentResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateLocationEfsRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateLocationEfsRequestRequestTypeDef",
+CreateLocationEfsRequestRequestTypeDef = TypedDict(
+    "CreateLocationEfsRequestRequestTypeDef",
     {
         "EfsFilesystemArn": str,
         "Ec2Config": "Ec2ConfigTypeDef",
+        "Subdirectory": NotRequired[str],
+        "Tags": NotRequired[Sequence["TagListEntryTypeDef"]],
     },
 )
-_OptionalCreateLocationEfsRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateLocationEfsRequestRequestTypeDef",
-    {
-        "Subdirectory": str,
-        "Tags": Sequence["TagListEntryTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateLocationEfsRequestRequestTypeDef(
-    _RequiredCreateLocationEfsRequestRequestTypeDef, _OptionalCreateLocationEfsRequestRequestTypeDef
-):
-    pass
-
 
 CreateLocationEfsResponseTypeDef = TypedDict(
     "CreateLocationEfsResponseTypeDef",
@@ -226,32 +204,36 @@ CreateLocationEfsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateLocationFsxWindowsRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateLocationFsxWindowsRequestRequestTypeDef",
+CreateLocationFsxLustreRequestRequestTypeDef = TypedDict(
+    "CreateLocationFsxLustreRequestRequestTypeDef",
+    {
+        "FsxFilesystemArn": str,
+        "SecurityGroupArns": Sequence[str],
+        "Subdirectory": NotRequired[str],
+        "Tags": NotRequired[Sequence["TagListEntryTypeDef"]],
+    },
+)
+
+CreateLocationFsxLustreResponseTypeDef = TypedDict(
+    "CreateLocationFsxLustreResponseTypeDef",
+    {
+        "LocationArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+CreateLocationFsxWindowsRequestRequestTypeDef = TypedDict(
+    "CreateLocationFsxWindowsRequestRequestTypeDef",
     {
         "FsxFilesystemArn": str,
         "SecurityGroupArns": Sequence[str],
         "User": str,
         "Password": str,
+        "Subdirectory": NotRequired[str],
+        "Tags": NotRequired[Sequence["TagListEntryTypeDef"]],
+        "Domain": NotRequired[str],
     },
 )
-_OptionalCreateLocationFsxWindowsRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateLocationFsxWindowsRequestRequestTypeDef",
-    {
-        "Subdirectory": str,
-        "Tags": Sequence["TagListEntryTypeDef"],
-        "Domain": str,
-    },
-    total=False,
-)
-
-
-class CreateLocationFsxWindowsRequestRequestTypeDef(
-    _RequiredCreateLocationFsxWindowsRequestRequestTypeDef,
-    _OptionalCreateLocationFsxWindowsRequestRequestTypeDef,
-):
-    pass
-
 
 CreateLocationFsxWindowsResponseTypeDef = TypedDict(
     "CreateLocationFsxWindowsResponseTypeDef",
@@ -261,38 +243,24 @@ CreateLocationFsxWindowsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateLocationHdfsRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateLocationHdfsRequestRequestTypeDef",
+CreateLocationHdfsRequestRequestTypeDef = TypedDict(
+    "CreateLocationHdfsRequestRequestTypeDef",
     {
         "NameNodes": Sequence["HdfsNameNodeTypeDef"],
         "AuthenticationType": HdfsAuthenticationTypeType,
         "AgentArns": Sequence[str],
+        "Subdirectory": NotRequired[str],
+        "BlockSize": NotRequired[int],
+        "ReplicationFactor": NotRequired[int],
+        "KmsKeyProviderUri": NotRequired[str],
+        "QopConfiguration": NotRequired["QopConfigurationTypeDef"],
+        "SimpleUser": NotRequired[str],
+        "KerberosPrincipal": NotRequired[str],
+        "KerberosKeytab": NotRequired[Union[bytes, IO[bytes], StreamingBody]],
+        "KerberosKrb5Conf": NotRequired[Union[bytes, IO[bytes], StreamingBody]],
+        "Tags": NotRequired[Sequence["TagListEntryTypeDef"]],
     },
 )
-_OptionalCreateLocationHdfsRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateLocationHdfsRequestRequestTypeDef",
-    {
-        "Subdirectory": str,
-        "BlockSize": int,
-        "ReplicationFactor": int,
-        "KmsKeyProviderUri": str,
-        "QopConfiguration": "QopConfigurationTypeDef",
-        "SimpleUser": str,
-        "KerberosPrincipal": str,
-        "KerberosKeytab": Union[bytes, IO[bytes], StreamingBody],
-        "KerberosKrb5Conf": Union[bytes, IO[bytes], StreamingBody],
-        "Tags": Sequence["TagListEntryTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateLocationHdfsRequestRequestTypeDef(
-    _RequiredCreateLocationHdfsRequestRequestTypeDef,
-    _OptionalCreateLocationHdfsRequestRequestTypeDef,
-):
-    pass
-
 
 CreateLocationHdfsResponseTypeDef = TypedDict(
     "CreateLocationHdfsResponseTypeDef",
@@ -302,29 +270,16 @@ CreateLocationHdfsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateLocationNfsRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateLocationNfsRequestRequestTypeDef",
+CreateLocationNfsRequestRequestTypeDef = TypedDict(
+    "CreateLocationNfsRequestRequestTypeDef",
     {
         "Subdirectory": str,
         "ServerHostname": str,
         "OnPremConfig": "OnPremConfigTypeDef",
+        "MountOptions": NotRequired["NfsMountOptionsTypeDef"],
+        "Tags": NotRequired[Sequence["TagListEntryTypeDef"]],
     },
 )
-_OptionalCreateLocationNfsRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateLocationNfsRequestRequestTypeDef",
-    {
-        "MountOptions": "NfsMountOptionsTypeDef",
-        "Tags": Sequence["TagListEntryTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateLocationNfsRequestRequestTypeDef(
-    _RequiredCreateLocationNfsRequestRequestTypeDef, _OptionalCreateLocationNfsRequestRequestTypeDef
-):
-    pass
-
 
 CreateLocationNfsResponseTypeDef = TypedDict(
     "CreateLocationNfsResponseTypeDef",
@@ -334,34 +289,20 @@ CreateLocationNfsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateLocationObjectStorageRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateLocationObjectStorageRequestRequestTypeDef",
+CreateLocationObjectStorageRequestRequestTypeDef = TypedDict(
+    "CreateLocationObjectStorageRequestRequestTypeDef",
     {
         "ServerHostname": str,
         "BucketName": str,
         "AgentArns": Sequence[str],
+        "ServerPort": NotRequired[int],
+        "ServerProtocol": NotRequired[ObjectStorageServerProtocolType],
+        "Subdirectory": NotRequired[str],
+        "AccessKey": NotRequired[str],
+        "SecretKey": NotRequired[str],
+        "Tags": NotRequired[Sequence["TagListEntryTypeDef"]],
     },
 )
-_OptionalCreateLocationObjectStorageRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateLocationObjectStorageRequestRequestTypeDef",
-    {
-        "ServerPort": int,
-        "ServerProtocol": ObjectStorageServerProtocolType,
-        "Subdirectory": str,
-        "AccessKey": str,
-        "SecretKey": str,
-        "Tags": Sequence["TagListEntryTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateLocationObjectStorageRequestRequestTypeDef(
-    _RequiredCreateLocationObjectStorageRequestRequestTypeDef,
-    _OptionalCreateLocationObjectStorageRequestRequestTypeDef,
-):
-    pass
-
 
 CreateLocationObjectStorageResponseTypeDef = TypedDict(
     "CreateLocationObjectStorageResponseTypeDef",
@@ -371,30 +312,17 @@ CreateLocationObjectStorageResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateLocationS3RequestRequestTypeDef = TypedDict(
-    "_RequiredCreateLocationS3RequestRequestTypeDef",
+CreateLocationS3RequestRequestTypeDef = TypedDict(
+    "CreateLocationS3RequestRequestTypeDef",
     {
         "S3BucketArn": str,
         "S3Config": "S3ConfigTypeDef",
+        "Subdirectory": NotRequired[str],
+        "S3StorageClass": NotRequired[S3StorageClassType],
+        "AgentArns": NotRequired[Sequence[str]],
+        "Tags": NotRequired[Sequence["TagListEntryTypeDef"]],
     },
 )
-_OptionalCreateLocationS3RequestRequestTypeDef = TypedDict(
-    "_OptionalCreateLocationS3RequestRequestTypeDef",
-    {
-        "Subdirectory": str,
-        "S3StorageClass": S3StorageClassType,
-        "AgentArns": Sequence[str],
-        "Tags": Sequence["TagListEntryTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateLocationS3RequestRequestTypeDef(
-    _RequiredCreateLocationS3RequestRequestTypeDef, _OptionalCreateLocationS3RequestRequestTypeDef
-):
-    pass
-
 
 CreateLocationS3ResponseTypeDef = TypedDict(
     "CreateLocationS3ResponseTypeDef",
@@ -404,32 +332,19 @@ CreateLocationS3ResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateLocationSmbRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateLocationSmbRequestRequestTypeDef",
+CreateLocationSmbRequestRequestTypeDef = TypedDict(
+    "CreateLocationSmbRequestRequestTypeDef",
     {
         "Subdirectory": str,
         "ServerHostname": str,
         "User": str,
         "Password": str,
         "AgentArns": Sequence[str],
+        "Domain": NotRequired[str],
+        "MountOptions": NotRequired["SmbMountOptionsTypeDef"],
+        "Tags": NotRequired[Sequence["TagListEntryTypeDef"]],
     },
 )
-_OptionalCreateLocationSmbRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateLocationSmbRequestRequestTypeDef",
-    {
-        "Domain": str,
-        "MountOptions": "SmbMountOptionsTypeDef",
-        "Tags": Sequence["TagListEntryTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateLocationSmbRequestRequestTypeDef(
-    _RequiredCreateLocationSmbRequestRequestTypeDef, _OptionalCreateLocationSmbRequestRequestTypeDef
-):
-    pass
-
 
 CreateLocationSmbResponseTypeDef = TypedDict(
     "CreateLocationSmbResponseTypeDef",
@@ -439,33 +354,20 @@ CreateLocationSmbResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateTaskRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateTaskRequestRequestTypeDef",
+CreateTaskRequestRequestTypeDef = TypedDict(
+    "CreateTaskRequestRequestTypeDef",
     {
         "SourceLocationArn": str,
         "DestinationLocationArn": str,
+        "CloudWatchLogGroupArn": NotRequired[str],
+        "Name": NotRequired[str],
+        "Options": NotRequired["OptionsTypeDef"],
+        "Excludes": NotRequired[Sequence["FilterRuleTypeDef"]],
+        "Schedule": NotRequired["TaskScheduleTypeDef"],
+        "Tags": NotRequired[Sequence["TagListEntryTypeDef"]],
+        "Includes": NotRequired[Sequence["FilterRuleTypeDef"]],
     },
 )
-_OptionalCreateTaskRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateTaskRequestRequestTypeDef",
-    {
-        "CloudWatchLogGroupArn": str,
-        "Name": str,
-        "Options": "OptionsTypeDef",
-        "Excludes": Sequence["FilterRuleTypeDef"],
-        "Schedule": "TaskScheduleTypeDef",
-        "Tags": Sequence["TagListEntryTypeDef"],
-        "Includes": Sequence["FilterRuleTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateTaskRequestRequestTypeDef(
-    _RequiredCreateTaskRequestRequestTypeDef, _OptionalCreateTaskRequestRequestTypeDef
-):
-    pass
-
 
 CreateTaskResponseTypeDef = TypedDict(
     "CreateTaskResponseTypeDef",
@@ -535,6 +437,24 @@ DescribeLocationEfsResponseTypeDef = TypedDict(
     },
 )
 
+DescribeLocationFsxLustreRequestRequestTypeDef = TypedDict(
+    "DescribeLocationFsxLustreRequestRequestTypeDef",
+    {
+        "LocationArn": str,
+    },
+)
+
+DescribeLocationFsxLustreResponseTypeDef = TypedDict(
+    "DescribeLocationFsxLustreResponseTypeDef",
+    {
+        "LocationArn": str,
+        "LocationUri": str,
+        "SecurityGroupArns": List[str],
+        "CreationTime": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DescribeLocationFsxWindowsRequestRequestTypeDef = TypedDict(
     "DescribeLocationFsxWindowsRequestRequestTypeDef",
     {
@@ -729,10 +649,9 @@ Ec2ConfigTypeDef = TypedDict(
 FilterRuleTypeDef = TypedDict(
     "FilterRuleTypeDef",
     {
-        "FilterType": Literal["SIMPLE_PATTERN"],
-        "Value": str,
+        "FilterType": NotRequired[Literal["SIMPLE_PATTERN"]],
+        "Value": NotRequired[str],
     },
-    total=False,
 )
 
 HdfsNameNodeTypeDef = TypedDict(
@@ -746,10 +665,9 @@ HdfsNameNodeTypeDef = TypedDict(
 ListAgentsRequestRequestTypeDef = TypedDict(
     "ListAgentsRequestRequestTypeDef",
     {
-        "MaxResults": int,
-        "NextToken": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListAgentsResponseTypeDef = TypedDict(
@@ -764,11 +682,10 @@ ListAgentsResponseTypeDef = TypedDict(
 ListLocationsRequestRequestTypeDef = TypedDict(
     "ListLocationsRequestRequestTypeDef",
     {
-        "MaxResults": int,
-        "NextToken": str,
-        "Filters": Sequence["LocationFilterTypeDef"],
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
+        "Filters": NotRequired[Sequence["LocationFilterTypeDef"]],
     },
-    total=False,
 )
 
 ListLocationsResponseTypeDef = TypedDict(
@@ -780,28 +697,14 @@ ListLocationsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListTagsForResourceRequestRequestTypeDef = TypedDict(
-    "_RequiredListTagsForResourceRequestRequestTypeDef",
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListTagsForResourceRequestRequestTypeDef = TypedDict(
-    "_OptionalListTagsForResourceRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListTagsForResourceRequestRequestTypeDef(
-    _RequiredListTagsForResourceRequestRequestTypeDef,
-    _OptionalListTagsForResourceRequestRequestTypeDef,
-):
-    pass
-
 
 ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef",
@@ -815,11 +718,10 @@ ListTagsForResourceResponseTypeDef = TypedDict(
 ListTaskExecutionsRequestRequestTypeDef = TypedDict(
     "ListTaskExecutionsRequestRequestTypeDef",
     {
-        "TaskArn": str,
-        "MaxResults": int,
-        "NextToken": str,
+        "TaskArn": NotRequired[str],
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListTaskExecutionsResponseTypeDef = TypedDict(
@@ -834,11 +736,10 @@ ListTaskExecutionsResponseTypeDef = TypedDict(
 ListTasksRequestRequestTypeDef = TypedDict(
     "ListTasksRequestRequestTypeDef",
     {
-        "MaxResults": int,
-        "NextToken": str,
-        "Filters": Sequence["TaskFilterTypeDef"],
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
+        "Filters": NotRequired[Sequence["TaskFilterTypeDef"]],
     },
-    total=False,
 )
 
 ListTasksResponseTypeDef = TypedDict(
@@ -862,18 +763,16 @@ LocationFilterTypeDef = TypedDict(
 LocationListEntryTypeDef = TypedDict(
     "LocationListEntryTypeDef",
     {
-        "LocationArn": str,
-        "LocationUri": str,
+        "LocationArn": NotRequired[str],
+        "LocationUri": NotRequired[str],
     },
-    total=False,
 )
 
 NfsMountOptionsTypeDef = TypedDict(
     "NfsMountOptionsTypeDef",
     {
-        "Version": NfsVersionType,
+        "Version": NotRequired[NfsVersionType],
     },
-    total=False,
 )
 
 OnPremConfigTypeDef = TypedDict(
@@ -886,52 +785,48 @@ OnPremConfigTypeDef = TypedDict(
 OptionsTypeDef = TypedDict(
     "OptionsTypeDef",
     {
-        "VerifyMode": VerifyModeType,
-        "OverwriteMode": OverwriteModeType,
-        "Atime": AtimeType,
-        "Mtime": MtimeType,
-        "Uid": UidType,
-        "Gid": GidType,
-        "PreserveDeletedFiles": PreserveDeletedFilesType,
-        "PreserveDevices": PreserveDevicesType,
-        "PosixPermissions": PosixPermissionsType,
-        "BytesPerSecond": int,
-        "TaskQueueing": TaskQueueingType,
-        "LogLevel": LogLevelType,
-        "TransferMode": TransferModeType,
-        "SecurityDescriptorCopyFlags": SmbSecurityDescriptorCopyFlagsType,
+        "VerifyMode": NotRequired[VerifyModeType],
+        "OverwriteMode": NotRequired[OverwriteModeType],
+        "Atime": NotRequired[AtimeType],
+        "Mtime": NotRequired[MtimeType],
+        "Uid": NotRequired[UidType],
+        "Gid": NotRequired[GidType],
+        "PreserveDeletedFiles": NotRequired[PreserveDeletedFilesType],
+        "PreserveDevices": NotRequired[PreserveDevicesType],
+        "PosixPermissions": NotRequired[PosixPermissionsType],
+        "BytesPerSecond": NotRequired[int],
+        "TaskQueueing": NotRequired[TaskQueueingType],
+        "LogLevel": NotRequired[LogLevelType],
+        "TransferMode": NotRequired[TransferModeType],
+        "SecurityDescriptorCopyFlags": NotRequired[SmbSecurityDescriptorCopyFlagsType],
     },
-    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "MaxItems": NotRequired[int],
+        "PageSize": NotRequired[int],
+        "StartingToken": NotRequired[str],
     },
-    total=False,
 )
 
 PrivateLinkConfigTypeDef = TypedDict(
     "PrivateLinkConfigTypeDef",
     {
-        "VpcEndpointId": str,
-        "PrivateLinkEndpoint": str,
-        "SubnetArns": List[str],
-        "SecurityGroupArns": List[str],
+        "VpcEndpointId": NotRequired[str],
+        "PrivateLinkEndpoint": NotRequired[str],
+        "SubnetArns": NotRequired[List[str]],
+        "SecurityGroupArns": NotRequired[List[str]],
     },
-    total=False,
 )
 
 QopConfigurationTypeDef = TypedDict(
     "QopConfigurationTypeDef",
     {
-        "RpcProtection": HdfsRpcProtectionType,
-        "DataTransferProtection": HdfsDataTransferProtectionType,
+        "RpcProtection": NotRequired[HdfsRpcProtectionType],
+        "DataTransferProtection": NotRequired[HdfsDataTransferProtectionType],
     },
-    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -955,34 +850,19 @@ S3ConfigTypeDef = TypedDict(
 SmbMountOptionsTypeDef = TypedDict(
     "SmbMountOptionsTypeDef",
     {
-        "Version": SmbVersionType,
+        "Version": NotRequired[SmbVersionType],
     },
-    total=False,
 )
 
-_RequiredStartTaskExecutionRequestRequestTypeDef = TypedDict(
-    "_RequiredStartTaskExecutionRequestRequestTypeDef",
+StartTaskExecutionRequestRequestTypeDef = TypedDict(
+    "StartTaskExecutionRequestRequestTypeDef",
     {
         "TaskArn": str,
+        "OverrideOptions": NotRequired["OptionsTypeDef"],
+        "Includes": NotRequired[Sequence["FilterRuleTypeDef"]],
+        "Excludes": NotRequired[Sequence["FilterRuleTypeDef"]],
     },
 )
-_OptionalStartTaskExecutionRequestRequestTypeDef = TypedDict(
-    "_OptionalStartTaskExecutionRequestRequestTypeDef",
-    {
-        "OverrideOptions": "OptionsTypeDef",
-        "Includes": Sequence["FilterRuleTypeDef"],
-        "Excludes": Sequence["FilterRuleTypeDef"],
-    },
-    total=False,
-)
-
-
-class StartTaskExecutionRequestRequestTypeDef(
-    _RequiredStartTaskExecutionRequestRequestTypeDef,
-    _OptionalStartTaskExecutionRequestRequestTypeDef,
-):
-    pass
-
 
 StartTaskExecutionResponseTypeDef = TypedDict(
     "StartTaskExecutionResponseTypeDef",
@@ -992,24 +872,13 @@ StartTaskExecutionResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredTagListEntryTypeDef = TypedDict(
-    "_RequiredTagListEntryTypeDef",
+TagListEntryTypeDef = TypedDict(
+    "TagListEntryTypeDef",
     {
         "Key": str,
+        "Value": NotRequired[str],
     },
 )
-_OptionalTagListEntryTypeDef = TypedDict(
-    "_OptionalTagListEntryTypeDef",
-    {
-        "Value": str,
-    },
-    total=False,
-)
-
-
-class TagListEntryTypeDef(_RequiredTagListEntryTypeDef, _OptionalTagListEntryTypeDef):
-    pass
-
 
 TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
@@ -1022,26 +891,24 @@ TagResourceRequestRequestTypeDef = TypedDict(
 TaskExecutionListEntryTypeDef = TypedDict(
     "TaskExecutionListEntryTypeDef",
     {
-        "TaskExecutionArn": str,
-        "Status": TaskExecutionStatusType,
+        "TaskExecutionArn": NotRequired[str],
+        "Status": NotRequired[TaskExecutionStatusType],
     },
-    total=False,
 )
 
 TaskExecutionResultDetailTypeDef = TypedDict(
     "TaskExecutionResultDetailTypeDef",
     {
-        "PrepareDuration": int,
-        "PrepareStatus": PhaseStatusType,
-        "TotalDuration": int,
-        "TransferDuration": int,
-        "TransferStatus": PhaseStatusType,
-        "VerifyDuration": int,
-        "VerifyStatus": PhaseStatusType,
-        "ErrorCode": str,
-        "ErrorDetail": str,
+        "PrepareDuration": NotRequired[int],
+        "PrepareStatus": NotRequired[PhaseStatusType],
+        "TotalDuration": NotRequired[int],
+        "TransferDuration": NotRequired[int],
+        "TransferStatus": NotRequired[PhaseStatusType],
+        "VerifyDuration": NotRequired[int],
+        "VerifyStatus": NotRequired[PhaseStatusType],
+        "ErrorCode": NotRequired[str],
+        "ErrorDetail": NotRequired[str],
     },
-    total=False,
 )
 
 TaskFilterTypeDef = TypedDict(
@@ -1056,11 +923,10 @@ TaskFilterTypeDef = TypedDict(
 TaskListEntryTypeDef = TypedDict(
     "TaskListEntryTypeDef",
     {
-        "TaskArn": str,
-        "Status": TaskStatusType,
-        "Name": str,
+        "TaskArn": NotRequired[str],
+        "Status": NotRequired[TaskStatusType],
+        "Name": NotRequired[str],
     },
-    total=False,
 )
 
 TaskScheduleTypeDef = TypedDict(
@@ -1078,135 +944,68 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateAgentRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateAgentRequestRequestTypeDef",
+UpdateAgentRequestRequestTypeDef = TypedDict(
+    "UpdateAgentRequestRequestTypeDef",
     {
         "AgentArn": str,
+        "Name": NotRequired[str],
     },
 )
-_OptionalUpdateAgentRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateAgentRequestRequestTypeDef",
-    {
-        "Name": str,
-    },
-    total=False,
-)
 
-
-class UpdateAgentRequestRequestTypeDef(
-    _RequiredUpdateAgentRequestRequestTypeDef, _OptionalUpdateAgentRequestRequestTypeDef
-):
-    pass
-
-
-_RequiredUpdateLocationHdfsRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateLocationHdfsRequestRequestTypeDef",
+UpdateLocationHdfsRequestRequestTypeDef = TypedDict(
+    "UpdateLocationHdfsRequestRequestTypeDef",
     {
         "LocationArn": str,
+        "Subdirectory": NotRequired[str],
+        "NameNodes": NotRequired[Sequence["HdfsNameNodeTypeDef"]],
+        "BlockSize": NotRequired[int],
+        "ReplicationFactor": NotRequired[int],
+        "KmsKeyProviderUri": NotRequired[str],
+        "QopConfiguration": NotRequired["QopConfigurationTypeDef"],
+        "AuthenticationType": NotRequired[HdfsAuthenticationTypeType],
+        "SimpleUser": NotRequired[str],
+        "KerberosPrincipal": NotRequired[str],
+        "KerberosKeytab": NotRequired[Union[bytes, IO[bytes], StreamingBody]],
+        "KerberosKrb5Conf": NotRequired[Union[bytes, IO[bytes], StreamingBody]],
+        "AgentArns": NotRequired[Sequence[str]],
     },
 )
-_OptionalUpdateLocationHdfsRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateLocationHdfsRequestRequestTypeDef",
-    {
-        "Subdirectory": str,
-        "NameNodes": Sequence["HdfsNameNodeTypeDef"],
-        "BlockSize": int,
-        "ReplicationFactor": int,
-        "KmsKeyProviderUri": str,
-        "QopConfiguration": "QopConfigurationTypeDef",
-        "AuthenticationType": HdfsAuthenticationTypeType,
-        "SimpleUser": str,
-        "KerberosPrincipal": str,
-        "KerberosKeytab": Union[bytes, IO[bytes], StreamingBody],
-        "KerberosKrb5Conf": Union[bytes, IO[bytes], StreamingBody],
-        "AgentArns": Sequence[str],
-    },
-    total=False,
-)
 
-
-class UpdateLocationHdfsRequestRequestTypeDef(
-    _RequiredUpdateLocationHdfsRequestRequestTypeDef,
-    _OptionalUpdateLocationHdfsRequestRequestTypeDef,
-):
-    pass
-
-
-_RequiredUpdateLocationNfsRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateLocationNfsRequestRequestTypeDef",
+UpdateLocationNfsRequestRequestTypeDef = TypedDict(
+    "UpdateLocationNfsRequestRequestTypeDef",
     {
         "LocationArn": str,
+        "Subdirectory": NotRequired[str],
+        "OnPremConfig": NotRequired["OnPremConfigTypeDef"],
+        "MountOptions": NotRequired["NfsMountOptionsTypeDef"],
     },
 )
-_OptionalUpdateLocationNfsRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateLocationNfsRequestRequestTypeDef",
-    {
-        "Subdirectory": str,
-        "OnPremConfig": "OnPremConfigTypeDef",
-        "MountOptions": "NfsMountOptionsTypeDef",
-    },
-    total=False,
-)
 
-
-class UpdateLocationNfsRequestRequestTypeDef(
-    _RequiredUpdateLocationNfsRequestRequestTypeDef, _OptionalUpdateLocationNfsRequestRequestTypeDef
-):
-    pass
-
-
-_RequiredUpdateLocationObjectStorageRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateLocationObjectStorageRequestRequestTypeDef",
+UpdateLocationObjectStorageRequestRequestTypeDef = TypedDict(
+    "UpdateLocationObjectStorageRequestRequestTypeDef",
     {
         "LocationArn": str,
+        "ServerPort": NotRequired[int],
+        "ServerProtocol": NotRequired[ObjectStorageServerProtocolType],
+        "Subdirectory": NotRequired[str],
+        "AccessKey": NotRequired[str],
+        "SecretKey": NotRequired[str],
+        "AgentArns": NotRequired[Sequence[str]],
     },
 )
-_OptionalUpdateLocationObjectStorageRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateLocationObjectStorageRequestRequestTypeDef",
-    {
-        "ServerPort": int,
-        "ServerProtocol": ObjectStorageServerProtocolType,
-        "Subdirectory": str,
-        "AccessKey": str,
-        "SecretKey": str,
-        "AgentArns": Sequence[str],
-    },
-    total=False,
-)
 
-
-class UpdateLocationObjectStorageRequestRequestTypeDef(
-    _RequiredUpdateLocationObjectStorageRequestRequestTypeDef,
-    _OptionalUpdateLocationObjectStorageRequestRequestTypeDef,
-):
-    pass
-
-
-_RequiredUpdateLocationSmbRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateLocationSmbRequestRequestTypeDef",
+UpdateLocationSmbRequestRequestTypeDef = TypedDict(
+    "UpdateLocationSmbRequestRequestTypeDef",
     {
         "LocationArn": str,
+        "Subdirectory": NotRequired[str],
+        "User": NotRequired[str],
+        "Domain": NotRequired[str],
+        "Password": NotRequired[str],
+        "AgentArns": NotRequired[Sequence[str]],
+        "MountOptions": NotRequired["SmbMountOptionsTypeDef"],
     },
 )
-_OptionalUpdateLocationSmbRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateLocationSmbRequestRequestTypeDef",
-    {
-        "Subdirectory": str,
-        "User": str,
-        "Domain": str,
-        "Password": str,
-        "AgentArns": Sequence[str],
-        "MountOptions": "SmbMountOptionsTypeDef",
-    },
-    total=False,
-)
-
-
-class UpdateLocationSmbRequestRequestTypeDef(
-    _RequiredUpdateLocationSmbRequestRequestTypeDef, _OptionalUpdateLocationSmbRequestRequestTypeDef
-):
-    pass
-
 
 UpdateTaskExecutionRequestRequestTypeDef = TypedDict(
     "UpdateTaskExecutionRequestRequestTypeDef",
@@ -1216,27 +1015,15 @@ UpdateTaskExecutionRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateTaskRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateTaskRequestRequestTypeDef",
+UpdateTaskRequestRequestTypeDef = TypedDict(
+    "UpdateTaskRequestRequestTypeDef",
     {
         "TaskArn": str,
+        "Options": NotRequired["OptionsTypeDef"],
+        "Excludes": NotRequired[Sequence["FilterRuleTypeDef"]],
+        "Schedule": NotRequired["TaskScheduleTypeDef"],
+        "Name": NotRequired[str],
+        "CloudWatchLogGroupArn": NotRequired[str],
+        "Includes": NotRequired[Sequence["FilterRuleTypeDef"]],
     },
 )
-_OptionalUpdateTaskRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateTaskRequestRequestTypeDef",
-    {
-        "Options": "OptionsTypeDef",
-        "Excludes": Sequence["FilterRuleTypeDef"],
-        "Schedule": "TaskScheduleTypeDef",
-        "Name": str,
-        "CloudWatchLogGroupArn": str,
-        "Includes": Sequence["FilterRuleTypeDef"],
-    },
-    total=False,
-)
-
-
-class UpdateTaskRequestRequestTypeDef(
-    _RequiredUpdateTaskRequestRequestTypeDef, _OptionalUpdateTaskRequestRequestTypeDef
-):
-    pass
